tasque
======

Command-line task handler with Trello integration

Installation
------------

From the project root directory::

    $ python setup.py install

Usage
-----

Simply run it::

    $ tasque

Use --help/-h to view info on the arguments::

    $ tasque --help

Release Notes
-------------

:0.0.1:
    Project created
